==> haskell-rio-orphans-0.1.1.0-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-rio-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: rio-orphans
version: 0.1.1.0
id: rio-orphans-0.1.1.0-CqG6xpbAOneJgvFYwHjgtd
key: rio-orphans-0.1.1.0-CqG6xpbAOneJgvFYwHjgtd
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/commercialhaskell/rio#readme
synopsis: Orphan instances for the RIO type in the rio package
description:
    See README and Haddocks at <https://www.stackage.org/package/rio-orphans>
category: Control
abi: 11fbfd654fc1d416392b53c2d9eedee4
exposed: True
exposed-modules:
    RIO.Orphans
hidden-modules: Paths_rio_orphans
import-dirs: /usr/lib/ghc-8.6.5/site-local/rio-orphans-0.1.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/rio-orphans-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/rio-orphans-0.1.1.0
hs-libraries: HSrio-orphans-0.1.1.0-CqG6xpbAOneJgvFYwHjgtd
depends:
    base-4.12.0.0 exceptions-0.10.2-F5iQJa9RoWHAiWKkKHwe3
    fast-logger-2.4.16-IPkSQQPy0a8FH2kw6Cm9rV
    monad-control-1.0.2.3-EKrTS47Oi8IKd1pTyskzd3
    monad-logger-0.3.30-4twYlJVifJDLt63DqDQmBG
    resourcet-1.2.2-8hEDHRutAsl8XBsaHNUdIq
    rio-0.1.11.0-8mwr5j0CL9r2TyMzDm1qRc
    transformers-base-0.4.5.2-KWttVZ7nb0vsLFTQBq79t
haddock-interfaces: /usr/share/doc/haskell-rio-orphans/html/rio-orphans.haddock
haddock-html: /usr/share/doc/haskell-rio-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rio-orphans-0.1.1.0-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-rio-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: rio-orphans
version: 0.1.1.0
id: rio-orphans-0.1.1.0-Al3qcFUpjY2L1JepbjMREB
key: rio-orphans-0.1.1.0-Al3qcFUpjY2L1JepbjMREB
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/commercialhaskell/rio#readme
synopsis: Orphan instances for the RIO type in the rio package
description:
    See README and Haddocks at <https://www.stackage.org/package/rio-orphans>
category: Control
abi: 97cbb3689baa1169b06184c1d02b0a81
exposed: True
exposed-modules:
    RIO.Orphans
hidden-modules: Paths_rio_orphans
import-dirs: /usr/lib/ghc-8.6.5/site-local/rio-orphans-0.1.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/rio-orphans-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/rio-orphans-0.1.1.0
hs-libraries: HSrio-orphans-0.1.1.0-Al3qcFUpjY2L1JepbjMREB
depends:
    base-4.12.0.0 exceptions-0.10.2-F5iQJa9RoWHAiWKkKHwe3
    fast-logger-2.4.16-40LqQV4hCVlDrT1Ol3Z7b4
    monad-control-1.0.2.3-EKrTS47Oi8IKd1pTyskzd3
    monad-logger-0.3.30-f2VRiadyj99WB3NKU59mz
    resourcet-1.2.2-8hEDHRutAsl8XBsaHNUdIq
    rio-0.1.11.0-8mwr5j0CL9r2TyMzDm1qRc
    transformers-base-0.4.5.2-KWttVZ7nb0vsLFTQBq79t
haddock-interfaces: /usr/share/doc/haskell-rio-orphans/html/rio-orphans.haddock
haddock-html: /usr/share/doc/haskell-rio-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
